import type { RefineThemedLayoutV2HeaderProps } from "@refinedev/antd";
import { useGetIdentity } from "@refinedev/core";
import {
  Layout as AntdLayout,
  Avatar,
  Space,
  Switch,
  theme,
  Typography,
  Button,
  Badge,
  Dropdown,
  MenuProps,
  Tooltip
} from "antd";
import React, { useContext } from "react";
import { ColorModeContext } from "../../contexts/color-mode";
import { 
  BellOutlined, 
  QuestionCircleOutlined,
  SettingOutlined,
  UserOutlined,
  LogoutOutlined,
  RocketOutlined
} from "@ant-design/icons";

const { Text, Title } = Typography;
const { useToken } = theme;

type IUser = {
  id: number;
  name: string;
  avatar: string;
  role?: string;
};

export const Header: React.FC<RefineThemedLayoutV2HeaderProps> = ({
  sticky = true,
}) => {
  const { token } = useToken();
  const { data: user } = useGetIdentity<IUser>();
  const { mode, setMode } = useContext(ColorModeContext);

  const headerStyles: React.CSSProperties = {
    backgroundColor: token.colorBgElevated,
    display: "flex",
    justifyContent: "space-between",
    alignItems: "center",
    padding: "0px 24px",
    height: "64px",
    boxShadow: "0 2px 4px rgba(0,0,0,0.08)",
  };

  if (sticky) {
    headerStyles.position = "sticky";
    headerStyles.top = 0;
    headerStyles.zIndex = 1;
  }
  
  const userMenuItems: MenuProps["items"] = [
    {
      key: "profile",
      icon: <UserOutlined />,
      label: "Profile",
    },
    {
      key: "settings",
      icon: <SettingOutlined />,
      label: "Settings",
    },
    {
      type: "divider",
    },
    {
      key: "logout",
      icon: <LogoutOutlined />,
      label: "Logout",
      danger: true,
    },
  ];
  
  const notificationItems: MenuProps["items"] = [
    {
      key: "1",
      label: (
        <div>
          <Text strong>New client deployment</Text>
          <div>Acme Corp SAAS deployment is now active</div>
          <Text type="secondary" style={{ fontSize: '12px' }}>5 minutes ago</Text>
        </div>
      ),
    },
    {
      key: "2",
      label: (
        <div>
          <Text strong>Alert: High CPU Usage</Text>
          <div>Client XYZ experiencing high resource utilization</div>
          <Text type="secondary" style={{ fontSize: '12px' }}>20 minutes ago</Text>
        </div>
      ),
    },
    {
      type: "divider",
    },
    {
      key: "view-all",
      label: "View all notifications",
    },
  ];

  return (
    <AntdLayout.Header style={headerStyles}>
      <div style={{ display: "flex", alignItems: "center" }}>
        <RocketOutlined style={{ fontSize: '24px', marginRight: '8px', color: token.colorPrimary }} />
        <Title level={4} style={{ margin: 0, marginRight: '24px' }}>BYOP</Title>
        <Text type="secondary">SAAS Deployment Automation Platform</Text>
      </div>
      
      <Space>
        <Tooltip title="Help & Resources">
          <Button
            type="text"
            icon={<QuestionCircleOutlined style={{ fontSize: '18px' }} />}
          />
        </Tooltip>
        
        <Dropdown
          menu={{ items: notificationItems }}
          placement="bottomRight"
          arrow
        >
          <Badge count={2}>
            <Button
              type="text" 
              icon={<BellOutlined style={{ fontSize: '18px' }} />}
            />
          </Badge>
        </Dropdown>
        
        <Switch
          checkedChildren="🌛"
          unCheckedChildren="🔆"
          onChange={() => setMode(mode === "light" ? "dark" : "light")}
          defaultChecked={mode === "dark"}
        />
        
        <Dropdown menu={{ items: userMenuItems }} placement="bottomRight">
          <Space style={{ marginLeft: "16px", cursor: "pointer" }}>
            {user?.name && (
              <div style={{ textAlign: "right" }}>
                <Text strong>{user.name}</Text>
                {user?.role && (
                  <div>
                    <Text type="secondary" style={{ fontSize: "12px" }}>
                      {user.role}
                    </Text>
                  </div>
                )}
              </div>
            )}
            {user?.avatar ? (
              <Avatar src={user?.avatar} alt={user?.name} />
            ) : (
              <Avatar icon={<UserOutlined />} />
            )}
          </Space>
        </Dropdown>
      </Space>
    </AntdLayout.Header>
  );
};
