import React, { useEffect, useState } from 'react';
import { Show } from "@refinedev/antd";
import { useShow, useList } from "@refinedev/core";
import { Card, Descriptions, Space, Tag, Typography, Table, Button, Alert } from 'antd';
import { RefreshButton, DateField } from '@refinedev/antd';
import { LinkOutlined, RocketOutlined } from '@ant-design/icons';

const { Title, Text } = Typography;

export const ComponentShow = () => {
  const { queryResult } = useShow();
  const { data, isLoading } = queryResult;
  const record = data?.data;

  // Fetch all blueprints to find which ones are using this component
  const { data: blueprintsData, isLoading: blueprintsLoading } = useList({
    resource: "blueprints",
    queryOptions: {
      enabled: !!record?.id,
    }
  });

  // Fetch deployments to find which ones use this component
  const { data: deploymentsData, isLoading: deploymentsLoading } = useList({
    resource: "deployments",
    queryOptions: {
      enabled: !!record?.id,
    }
  });

  // Filter blueprints to find which ones use this component
  const relevantBlueprints = blueprintsData?.data?.filter((blueprint: any) => {
    return blueprint.config?.components?.some((component: any) => component.id === record?.id);
  }) || [];

  // Filter deployments associated with blueprints using this component
  const relevantDeployments = deploymentsData?.data?.filter((deployment: any) => {
    // Find an app that uses this component and matches the deployment's appId
    return relevantBlueprints.some((blueprint: any) =>
      blueprint.id === deployment.appId
    );
  }) || [];

  return (
    <Show
      isLoading={isLoading}
      headerButtons={[<RefreshButton />]}
    >
      <Title level={4}>Component Details</Title>

      <Card style={{ marginBottom: 20 }}>
        <Descriptions bordered column={2}>
          <Descriptions.Item label="ID">{record?.id}</Descriptions.Item>
          <Descriptions.Item label="Name">{record?.name}</Descriptions.Item>
          <Descriptions.Item label="Type">
            <Tag color="blue">{record?.type}</Tag>
          </Descriptions.Item>
          <Descriptions.Item label="Language">{record?.language}</Descriptions.Item>
          <Descriptions.Item label="Version">{record?.version}</Descriptions.Item>
          <Descriptions.Item label="Description" span={2}>
            {record?.description}
          </Descriptions.Item>
        </Descriptions>
      </Card>

      <Card title="Configuration" style={{ marginBottom: 20 }}>
        <Descriptions bordered column={2}>
          <Descriptions.Item label="Config File" span={2}>
            {record?.configFile}
          </Descriptions.Item>
          <Descriptions.Item label="Environment Variables" span={2}>
            <pre>{record?.envVariables}</pre>
          </Descriptions.Item>
        </Descriptions>
      </Card>

      <Card title="Source Code" style={{ marginBottom: 20 }}>
        <Descriptions bordered column={2}>
          <Descriptions.Item label="Repository">{record?.repository}</Descriptions.Item>
          <Descriptions.Item label="Branch">{record?.branch}</Descriptions.Item>
          <Descriptions.Item label="Build Command" span={2}>{record?.buildCommand}</Descriptions.Item>
        </Descriptions>
      </Card>

      <Card title="Resources" style={{ marginBottom: 20 }}>
        <Descriptions bordered column={2}>
          <Descriptions.Item label="Resources" span={2}>
            <pre>{record?.resources}</pre>
          </Descriptions.Item>
          <Descriptions.Item label="Scale Settings" span={2}>
            <pre>{record?.scaleSettings}</pre>
          </Descriptions.Item>
        </Descriptions>
      </Card>

      <Card title="Used in Blueprints" style={{ marginBottom: 20 }}>
        {blueprintsLoading ? (
          <div>Loading blueprints...</div>
        ) : relevantBlueprints.length > 0 ? (
          <Table
            dataSource={relevantBlueprints}
            rowKey="id"
            pagination={false}
          >
            <Table.Column title="ID" dataIndex="id" />
            <Table.Column
              title="Blueprint Name"
              dataIndex="name"
              render={(value, record: any) => (
                <Button
                  type="link"
                  href={`/blueprints/show/${record.id}`}
                >
                  {value}
                </Button>
              )}
            />
            <Table.Column
              title="Version"
              dataIndex="version"
            />
            <Table.Column
              title="Components"
              render={(_, record: any) => (
                <Tag color="blue">{record.config?.components?.length || 0} Components</Tag>
              )}
            />
          </Table>
        ) : (
          <Alert message="This component is not used in any blueprints yet." type="info" />
        )}
      </Card>

      <Card title="Active Deployments" style={{ marginBottom: 20 }}>
        {deploymentsLoading ? (
          <div>Loading deployments...</div>
        ) : relevantDeployments.length > 0 ? (
          <Table
            dataSource={relevantDeployments}
            rowKey="id"
            pagination={false}
          >
            <Table.Column title="ID" dataIndex="id" />
            <Table.Column
              title="Deployment Name"
              dataIndex="name"
              render={(value, record: any) => (
                <Button
                  type="link"
                  href={`/deployments/show/${record.id}`}
                >
                  {value}
                </Button>
              )}
            />
            <Table.Column
              title="Status"
              dataIndex="status"
              render={(value) => (
                <Tag color={value === 'active' ? 'green' : 'orange'}>
                  {value.toUpperCase()}
                </Tag>
              )}
            />
            <Table.Column
              title="Client"
              dataIndex="clientName"
            />
            <Table.Column
              title="Environment"
              dataIndex="environment"
              render={(value) => (
                <Tag color={value === 'production' ? 'red' : value === 'staging' ? 'orange' : 'green'}>
                  {value.toUpperCase()}
                </Tag>
              )}
            />
          </Table>
        ) : (
          <Alert message="This component is not used in any active deployments yet." type="info" />
        )}
      </Card>

      <Card title="Metadata">
        <Descriptions bordered column={2}>
          <Descriptions.Item label="Created At">
            <DateField value={record?.createdAt} format="LLL" />
          </Descriptions.Item>
          <Descriptions.Item label="Updated At">
            <DateField value={record?.updatedAt} format="LLL" />
          </Descriptions.Item>
          <Descriptions.Item label="Created By">{record?.createdBy}</Descriptions.Item>
        </Descriptions>
      </Card>
    </Show>
  );
};
