import { useList } from "@refinedev/core";
import { 
  Card, 
  Row, 
  Col, 
  Typography, 
  Statistic, 
  Table, 
  Progress, 
  Timeline,
  Space,
  Button,
  Tag,
  Divider 
} from "antd";
import {
  RocketOutlined,
  UserOutlined,
  FileOutlined,
  CheckCircleOutlined,
  WarningOutlined,
  ClockCircleOutlined,
  PlusOutlined
} from "@ant-design/icons";
import {
  AreaChart,
  Area,
  XAxis,
  YAxis,
  CartesianGrid,
  Tooltip,
  ResponsiveContainer,
  PieChart,
  Pie,
  Cell
} from "recharts";

const { Title, Text } = Typography;

// Mock data for charts
const deploymentTrendData = [
  { name: "Jan", deployments: 10 },
  { name: "Feb", deployments: 15 },
  { name: "Mar", deployments: 20 },
  { name: "Apr", deployments: 25 },
  { name: "May", deployments: 40 },
];

const templateUsageData = [
  { name: "Docker", value: 45 },
  { name: "Docker Compose", value: 35 },
  { name: "Kubernetes", value: 20 },
];

const COLORS = ["#0088FE", "#00C49F", "#FFBB28"];

export const DashboardOverview = () => {
  // In a real implementation, these would come from API calls
  const { data: deploymentsData } = useList({
    resource: "deployments",
  });

  const { data: clientsData } = useList({
    resource: "clients",
  });

  const { data: blueprintsData } = useList({
    resource: "blueprints",
  });

  // Add loading states for dashboard statistics
  const deploymentsLoading = deploymentsData?.loading || false;
  const clientsLoading = clientsData?.loading || false;
  const blueprintsLoading = blueprintsData?.loading || false;
  
  // Calculate summary statistics
  const totalDeployments = deploymentsData?.data?.length || 0;
  const activeDeployments = deploymentsData?.data?.filter(item => item.status === "active")?.length || 0;
  const totalClients = clientsData?.data?.length || 0;
  const totalBlueprints = blueprintsData?.data?.length || 0;
  
  // Mock recent deployments data
  const recentDeployments = [
    { id: 1, name: "Acme Corp CRM", clientName: "Acme Corp", status: "active", date: "2025-05-08 14:30" },
    { id: 2, name: "GlobalTech ERP", clientName: "GlobalTech", status: "pending", date: "2025-05-08 10:15" },
    { id: 3, name: "InnoSoft Analytics", clientName: "InnoSoft", status: "active", date: "2025-05-07 16:45" },
  ];

  // Mock recent activity data
  const recentActivity = [
    { id: 1, action: "Deployment created", target: "Acme Corp CRM", user: "John Admin", time: "2025-05-08 14:25" },
    { id: 2, action: "Template updated", target: "Node.js Microservice", user: "Sarah Developer", time: "2025-05-08 11:30" },
    { id: 3, action: "Client onboarded", target: "GlobalTech", user: "John Admin", time: "2025-05-08 09:45" },
    { id: 4, action: "Support ticket resolved", target: "#1234", user: "Mike Support", time: "2025-05-07 17:20" },
  ];

  return (
    <>
      <div style={{ display: "flex", justifyContent: "space-between", alignItems: "center", marginBottom: 16 }}>
        <Title level={4}>BYOP Dashboard Overview</Title>
        <Space>
          <Button icon={<PlusOutlined />} type="primary">
            New Deployment
          </Button>
        </Space>
      </div>

      {/* Summary Statistics */}
      <Row gutter={[16, 16]}>
        <Col xs={24} sm={12} md={6}>
          <Card>
            <Statistic
              title="Total Deployments"
              value={totalDeployments}
              prefix={<RocketOutlined />}
              valueStyle={{ color: "#3f8600" }}
              loading={deploymentsLoading}
            />
            <div style={{ marginTop: 8 }}>
              <Text type="secondary">{activeDeployments} active</Text>
            </div>
          </Card>
        </Col>
        <Col xs={24} sm={12} md={6}>
          <Card>
            <Statistic
              title="Total Clients"
              value={totalClients}
              prefix={<UserOutlined />}
              valueStyle={{ color: "#1890ff" }}
              loading={clientsLoading}
            />
            <div style={{ marginTop: 8 }}>
              <Text type="secondary">Across multiple industries</Text>
            </div>
          </Card>
        </Col>
        <Col xs={24} sm={12} md={6}>
          <Card>
            <Statistic
              title="Deployment Blueprints"
              value={totalBlueprints}
              prefix={<FileOutlined />}
              valueStyle={{ color: "#722ed1" }}
              loading={blueprintsLoading}
            />
            <div style={{ marginTop: 8 }}>
              <Text type="secondary">Ready for deployment</Text>
            </div>
          </Card>
        </Col>
        <Col xs={24} sm={12} md={6}>
          <Card>
            <Statistic
              title="System Health"
              value="98%"
              prefix={<CheckCircleOutlined />}
              valueStyle={{ color: "#3f8600" }}
            />
            <div style={{ marginTop: 8 }}>
              <Progress percent={98} size="small" showInfo={false} />
            </div>
          </Card>
        </Col>
      </Row>

      <Row gutter={[16, 16]} style={{ marginTop: 16 }}>
        {/* Deployment Trends */}
        <Col xs={24} lg={12}>
          <Card title="Deployment Trends">
            <ResponsiveContainer width="100%" height={250}>
              <AreaChart
                data={deploymentTrendData}
                margin={{ top: 10, right: 30, left: 0, bottom: 0 }}
              >
                <CartesianGrid strokeDasharray="3 3" />
                <XAxis dataKey="name" />
                <YAxis />
                <Tooltip />
                <Area type="monotone" dataKey="deployments" stroke="#8884d8" fill="#8884d8" />
              </AreaChart>
            </ResponsiveContainer>
          </Card>
        </Col>

        {/* Blueprint Usage */}
        <Col xs={24} lg={12}>
          <Card title="Blueprint Usage">
            <Row>
              <Col span={12}>
                <ResponsiveContainer width="100%" height={250}>
                  <PieChart>
                    <Pie
                      data={templateUsageData}
                      cx="50%"
                      cy="50%"
                      labelLine={false}
                      outerRadius={80}
                      fill="#8884d8"
                      dataKey="value"
                      label={({ name, percent }) => `${name} ${(percent * 100).toFixed(0)}%`}
                    >
                      {templateUsageData.map((entry, index) => (
                        <Cell key={`cell-${index}`} fill={COLORS[index % COLORS.length]} />
                      ))}
                    </Pie>
                    <Tooltip />
                  </PieChart>
                </ResponsiveContainer>
              </Col>
              <Col span={12}>
                <div style={{ paddingLeft: 20 }}>
                  {templateUsageData.map((item, index) => (
                    <div key={item.name} style={{ marginBottom: 10 }}>
                      <div style={{ display: "flex", alignItems: "center" }}>
                        <div
                          style={{
                            width: 10,
                            height: 10,
                            backgroundColor: COLORS[index % COLORS.length],
                            marginRight: 8,
                          }}
                        />
                        <Text>{item.name}</Text>
                      </div>
                      <Text type="secondary">{item.value} deployments</Text>
                    </div>
                  ))}
                </div>
              </Col>
            </Row>
          </Card>
        </Col>
      </Row>

      <Row gutter={[16, 16]} style={{ marginTop: 16 }}>
        {/* Recent Deployments */}
        <Col xs={24} lg={12}>
          <Card title="Recent Deployments" extra={<Button type="link">View All</Button>}>
            <Table
              dataSource={recentDeployments}
              pagination={false}
              rowKey="id"
              size="small"
              columns={[
                { title: "Name", dataIndex: "name", key: "name", render: (text) => <Text strong>{text}</Text> },
                { title: "Client", dataIndex: "clientName", key: "clientName" },
                { 
                  title: "Status", 
                  dataIndex: "status",
                  key: "status",
                  render: (status) => (
                    status === "active" ? 
                      <Tag color="green">Active</Tag> : 
                      <Tag color="orange">Pending</Tag>
                  )
                },
                { title: "Date", dataIndex: "date", key: "date" },
              ]}
            />
          </Card>
        </Col>

        {/* Recent Activity */}
        <Col xs={24} lg={12}>
          <Card title="Recent Activity" extra={<Button type="link">View All</Button>}>
            <Timeline
              items={recentActivity.map(item => ({
                dot: item.action.includes("Deployment") ? <RocketOutlined style={{ color: "#1890ff" }} /> : 
                     item.action.includes("Template") ? <FileOutlined style={{ color: "#722ed1" }} /> :
                     item.action.includes("Client") ? <UserOutlined style={{ color: "#52c41a" }} /> :
                     <ClockCircleOutlined style={{ color: "#faad14" }} />,
                children: (
                  <>
                    <Text strong>{item.action}</Text>
                    <div>{item.target}</div>
                    <div>
                      <Text type="secondary">{item.user} - {item.time}</Text>
                    </div>
                  </>
                )
              }))}
            />
          </Card>
        </Col>
      </Row>

      <Row gutter={[16, 16]} style={{ marginTop: 16 }}>
        <Col span={24}>
          <Card title="System Alerts" extra={<Button type="link">View All</Button>}>
            <Timeline
              items={[
                {
                  dot: <WarningOutlined style={{ color: "#ff4d4f" }} />,
                  color: "red",
                  children: (
                    <>
                      <Text strong>High CPU Usage</Text>
                      <div>Client: GlobalTech ERP - Container CPU usage exceeds 90%</div>
                      <div><Text type="secondary">2025-05-08 13:45</Text></div>
                    </>
                  )
                },
                {
                  dot: <WarningOutlined style={{ color: "#faad14" }} />,
                  color: "orange",
                  children: (
                    <>
                      <Text strong>Database Memory Usage</Text>
                      <div>Client: InnoSoft Analytics - Database memory utilization above 75%</div>
                      <div><Text type="secondary">2025-05-08 12:30</Text></div>
                    </>
                  )
                }
              ]}
            />
          </Card>
        </Col>
      </Row>
    </>
  );
};